代码拉取完成,页面将自动刷新
同步操作将从 src-openEuler/lldpad 强制同步,此操作会覆盖自 Fork 仓库以来所做的任何修改,且无法恢复!!!
确定后同步将在后台操作,完成时将刷新页面,请耐心等待。
From 2446318f61b3161cccc7c4c467f3a58be33a9c16 Mon Sep 17 00:00:00 2001
From: Aaron Conole <aconole@redhat.com>
Date: Fri, 11 Dec 2020 12:34:56 -0500
Subject: [PATCH] tx: rename variable
This was originally intended to be part of f91cf35f5871 ("tx: when ...")
but was omitted in error. Addresses the original comment.
Signed-off-by: Aaron Conole <aconole@redhat.com>
---
lldp/tx.c | 6 +++---
1 file changed, 3 insertions(+), 3 deletions(-)
diff --git a/lldp/tx.c b/lldp/tx.c
index 9b36071..9ecd9d1 100644
--- a/lldp/tx.c
+++ b/lldp/tx.c
@@ -330,15 +330,15 @@ void process_tx_idle(UNUSED struct lldp_agent *agent)
return;
}
/* we ignore 'state' value in the case that we have recently transitioned
* to the shutdown state (in the case of the 'tx' state change) to allow
* for transmitting the ttl==0 as required by the IEEE standard. */
void process_tx_shutdown_frame(struct port *port, struct lldp_agent *agent,
- bool ignoreState)
+ bool ignoreStatus)
{
if (agent->adminStatus != enabledRxTx &&
agent->adminStatus != enabledTxOnly) {
- if (!ignoreState) {
+ if (!ignoreStatus) {
return;
}
}
@@ -330,15 +330,15 @@ void process_tx_idle(UNUSED struct lldp_agent *agent)
return;
}
-/* we ignore 'state' value in the case that we have recently transitioned
+/* we ignore 'adminStatus' in the case that we have recently transitioned
* to the shutdown state (in the case of the 'tx' state change) to allow
* for transmitting the ttl==0 as required by the IEEE standard. */
--
2.33.0
此处可能存在不合适展示的内容,页面不予展示。您可通过相关编辑功能自查并修改。
如您确认内容无涉及 不当用语 / 纯广告导流 / 暴力 / 低俗色情 / 侵权 / 盗版 / 虚假 / 无价值内容或违法国家有关法律法规的内容,可点击提交进行申诉,我们将尽快为您处理。